"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const semver = require("semver");
const shell_1 = require("../../lib/shell");
const npm_1 = require("../../lib/npm");
async function run(ctx) {
    const environment = ctx.env.require('ENVIRONMENT');
    if (environment === 'DEVELOPMENT') {
        ctx.serverlog.info(`Not fetching updates for ${ctx.c.bold('DEVELOPMENT')} environment.`);
        return;
    }
    const dir = path.dirname(path.dirname(ctx.bindir));
    const distTag = environment === 'STAGING' ? 'staging' : 'latest';
    ctx.userlog.info('Checking for build process updates...');
    const pkgInfo = await npm_1.readPackageJson(dir, 'server');
    const pkgDist = `${pkgInfo.name}@${distTag}`;
    const { stdout } = await shell_1.execFilep('npm', ['info', pkgInfo.name, `dist-tags.${distTag}`, '--json'], { cwd: dir });
    const currentVersion = pkgInfo.version;
    const latestVersion = JSON.parse(stdout);
    if (semver.lt(currentVersion, latestVersion)) {
        ctx.serverlog.info({ currentVersion, latestVersion }, `${ctx.c.bold(pkgDist)} out of date, updating...`);
        await shell_1.runcmd({ outlog: ctx.serverlog }, 'npm', ['install', '-g', `${pkgInfo.name}@${latestVersion}`], { cwd: dir });
    }
    else {
        ctx.serverlog.info({ currentVersion, latestVersion }, 'No update needed.');
    }
}
exports.run = run;
