"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ERROR_S3_NO_SUCH_KEY = new Error('NoSuchKey');
class S3Client {
    constructor(client) {
        this.client = client;
    }
    download(bucket, key, ws) {
        return new Promise((resolve, reject) => {
            ws.on('error', err => {
                reject(err);
            });
            const rs = this.client.getObject({ Bucket: bucket, Key: key }).createReadStream();
            rs.on('error', (err) => {
                if (err.code === 'NoSuchKey') {
                    return reject(exports.ERROR_S3_NO_SUCH_KEY);
                }
                reject(err);
            });
            rs.on('end', () => {
                resolve();
            });
            rs.pipe(ws);
        });
    }
    async upload(bucket, key, rs, params) {
        await this.client.upload({ ...params, Body: rs, Bucket: bucket, Key: key }).promise();
    }
}
exports.S3Client = S3Client;
class ECRClient {
    constructor(client) {
        this.client = client;
    }
    async getLoginCredentials() {
        const res = await this.client.getAuthorizationToken().promise();
        if (!res.authorizationData) {
            throw new Error('missing authorization data');
        }
        // Just use the first... ?
        const [data] = res.authorizationData;
        if (!data.authorizationToken) {
            throw new Error('missing authorization token');
        }
        if (!data.proxyEndpoint) {
            throw new Error('missing proxy endpoint');
        }
        const credentials = Buffer.from(data.authorizationToken, 'base64').toString();
        const [username, password] = credentials.split(':');
        return { username, password, endpoint: data.proxyEndpoint };
    }
}
exports.ECRClient = ECRClient;
