"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const guards_1 = require("../guards");
const errors_1 = require("../errors");
const fs_1 = require("./fs");
exports.PROJECT_FILE = 'ionic.config.json';
async function readProjectFile(ctx) {
    try {
        const f = await fs_1.fsReadFile(path.resolve(ctx.codedir, exports.PROJECT_FILE), { encoding: 'utf8' });
        const o = JSON.parse(f);
        if (!guards_1.isProjectFile(o)) {
            throw new errors_1.JobException(`Invalid format in ${exports.PROJECT_FILE}.`, 'user');
        }
        return o;
    }
    catch (e) {
        if (e.code === 'ENOENT') {
            throw new errors_1.JobException(`Missing ${exports.PROJECT_FILE} in app.`, 'user');
        }
        else if (e instanceof SyntaxError) {
            throw new errors_1.JobException(`Invalid JSON in ${exports.PROJECT_FILE}.`, 'user');
        }
        throw e;
    }
}
exports.readProjectFile = readProjectFile;
