"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process = require("child_process");
const util_1 = require("util");
const errors_1 = require("../errors");
exports.execFilep = util_1.promisify(child_process.execFile);
function runcmd({ outlog, errlog }, cmd, args, opts) {
    if (!errlog) {
        errlog = outlog;
    }
    const cmdoutlog = outlog.child({ cmd: `${cmd}` });
    const cmderrlog = errlog.child({ cmd: `${cmd}` });
    const p = child_process.spawn(cmd, args, opts);
    let stdoutChunk = '';
    let stderrChunk = '';
    p.stdout.on('data', chunk => {
        stdoutChunk += chunk.toString();
        if (stdoutChunk.endsWith('\n')) {
            cmdoutlog.info(stdoutChunk.replace(/\n$/g, ''));
            stdoutChunk = '';
        }
    });
    p.stderr.on('data', chunk => {
        stderrChunk += chunk.toString();
        if (stderrChunk.endsWith('\n')) {
            cmderrlog.info(stderrChunk.replace(/\n$/g, ''));
            stderrChunk = '';
        }
    });
    return new Promise((resolve, reject) => {
        p.on('close', code => {
            if (code > 0) {
                reject(new errors_1.ShellException('Subcommand returned a non-zero exit code.', 'server', code));
            }
            else {
                resolve(code);
            }
        });
        p.on('error', err => {
            reject(err);
        });
    });
}
exports.runcmd = runcmd;
function prettyArgv(argv) {
    return argv.length > 0 ? argv.map(a => a.includes(' ') ? `"${a}"` : a).join(' ') : '';
}
exports.prettyArgv = prettyArgv;
